@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2004, 2005 Topspin Communications.  All rights reserved.
  * Copyright (c) 2004 Intel Corporation.  All rights reserved.
- * Copyright (c) 2005, 2006 Cisco Systems.  All rights reserved.
+ * Copyright (c) 2005, 2006, 2007 Cisco Systems, Inc.  All rights reserved.
  * Copyright (c) 2005 PathScale, Inc.  All rights reserved.
  *
  * This software is available to you under a choice of one of two
@@ -31,8 +31,6 @@
  * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
- *
- * $Id: verbs.h 6428 2006-04-11 20:40:26Z roland $
  */
 
 #ifndef INFINIBAND_VERBS_H
@@ -41,8 +39,6 @@
 #include <stdint.h>
 #include <pthread.h>
 
-#include <sysfs/libsysfs.h>
-
 #ifdef __cplusplus
 #  define BEGIN_C_DECLS extern "C" {
 #  define END_C_DECLS   }
@@ -68,9 +64,17 @@ union ibv_gid {
 };
 
 enum ibv_node_type {
-	IBV_NODE_CA 	= 1,
+	IBV_NODE_UNKNOWN	= -1,
+	IBV_NODE_CA 		= 1,
 	IBV_NODE_SWITCH,
-	IBV_NODE_ROUTER
+	IBV_NODE_ROUTER,
+	IBV_NODE_RNIC
+};
+
+enum ibv_transport_type {
+	IBV_TRANSPORT_UNKNOWN	= -1,
+	IBV_TRANSPORT_IB	= 0,
+	IBV_TRANSPORT_IWARP
 };
 
 enum ibv_device_cap_flags {
@@ -88,7 +92,7 @@ enum ibv_device_cap_flags {
 	IBV_DEVICE_SYS_IMAGE_GUID	= 1 << 11,
 	IBV_DEVICE_RC_RNR_NAK_GEN	= 1 << 12,
 	IBV_DEVICE_SRQ_RESIZE		= 1 << 13,
-	IBV_DEVICE_N_NOTIFY_CQ		= 1 << 14,
+	IBV_DEVICE_N_NOTIFY_CQ		= 1 << 14
 };
 
 enum ibv_atomic_cap {
@@ -196,7 +200,8 @@ enum ibv_event_type {
 	IBV_EVENT_SM_CHANGE,
 	IBV_EVENT_SRQ_ERR,
 	IBV_EVENT_SRQ_LIMIT_REACHED,
-	IBV_EVENT_QP_LAST_WQE_REACHED
+	IBV_EVENT_QP_LAST_WQE_REACHED,
+	IBV_EVENT_CLIENT_REREGISTER
 };
 
 struct ibv_async_event {
@@ -283,14 +288,34 @@ struct ibv_pd {
 	uint32_t		handle;
 };
 
+enum ibv_rereg_mr_flags {
+	IBV_REREG_MR_CHANGE_TRANSLATION	= (1 << 0),
+	IBV_REREG_MR_CHANGE_PD		= (1 << 1),
+	IBV_REREG_MR_CHANGE_ACCESS	= (1 << 2),
+	IBV_REREG_MR_KEEP_VALID		= (1 << 3)
+};
+
 struct ibv_mr {
 	struct ibv_context     *context;
 	struct ibv_pd	       *pd;
+	void		       *addr;
+	size_t			length;
 	uint32_t		handle;
 	uint32_t		lkey;
 	uint32_t		rkey;
 };
 
+enum ibv_mw_type {
+	IBV_MW_TYPE_1			= 1,
+	IBV_MW_TYPE_2			= 2
+};
+
+struct ibv_mw {
+	struct ibv_context     *context;
+	struct ibv_pd	       *pd;
+	uint32_t		rkey;
+};
+
 struct ibv_global_route {
 	union ibv_gid		dgid;
 	uint32_t		flow_label;
@@ -299,6 +324,15 @@ struct ibv_global_route {
 	uint8_t			traffic_class;
 };
 
+struct ibv_grh {
+	uint32_t		version_tclass_flow;
+	uint16_t		paylen;
+	uint8_t			next_hdr;
+	uint8_t			hop_limit;
+	union ibv_gid		sgid;
+	union ibv_gid		dgid;
+};
+
 enum ibv_rate {
 	IBV_RATE_MAX      = 0,
 	IBV_RATE_2_5_GBPS = 2,
@@ -338,7 +372,7 @@ struct ibv_ah_attr {
 
 enum ibv_srq_attr_mask {
 	IBV_SRQ_MAX_WR	= 1 << 0,
-	IBV_SRQ_LIMIT	= 1 << 1,
+	IBV_SRQ_LIMIT	= 1 << 1
 };
 
 struct ibv_srq_attr {
@@ -468,8 +502,8 @@ struct ibv_sge {
 };
 
 struct ibv_send_wr {
-	struct ibv_send_wr     *next;
 	uint64_t		wr_id;
+	struct ibv_send_wr     *next;
 	struct ibv_sge	       *sg_list;
 	int			num_sge;
 	enum ibv_wr_opcode	opcode;
@@ -495,12 +529,21 @@ struct ibv_send_wr {
 };
 
 struct ibv_recv_wr {
-	struct ibv_recv_wr     *next;
 	uint64_t		wr_id;
+	struct ibv_recv_wr     *next;
 	struct ibv_sge	       *sg_list;
 	int			num_sge;
 };
 
+struct ibv_mw_bind {
+	uint64_t		wr_id;
+	struct ibv_mr	       *mr;
+	void		       *addr;
+	size_t			length;
+	enum ibv_send_flags	send_flags;
+	enum ibv_access_flags	mw_access_flags;
+};
+
 struct ibv_srq {
 	struct ibv_context     *context;
 	void		       *srq_context;
@@ -530,11 +573,14 @@ struct ibv_qp {
 };
 
 struct ibv_comp_channel {
+	struct ibv_context     *context;
 	int			fd;
+	int			refcnt;
 };
 
 struct ibv_cq {
 	struct ibv_context     *context;
+	struct ibv_comp_channel *channel;
 	void		       *cq_context;
 	uint32_t		handle;
 	int			cqe;
@@ -559,11 +605,23 @@ struct ibv_device_ops {
 	void			(*free_context)(struct ibv_context *context);
 };
 
+enum {
+	IBV_SYSFS_NAME_MAX	= 64,
+	IBV_SYSFS_PATH_MAX	= 256
+};
+
 struct ibv_device {
-	struct sysfs_class_device *dev;
-	struct sysfs_class_device *ibdev;
-	struct ibv_driver         *driver;
-	struct ibv_device_ops      ops;
+	struct ibv_device_ops	ops;
+	enum ibv_node_type	node_type;
+	enum ibv_transport_type	transport_type;
+	/* Name of underlying kernel IB device, eg "mthca0" */
+	char			name[IBV_SYSFS_NAME_MAX];
+	/* Name of uverbs device, eg "uverbs0" */
+	char			dev_name[IBV_SYSFS_NAME_MAX];
+	/* Path to infiniband_verbs class device in sysfs */
+	char			dev_path[IBV_SYSFS_PATH_MAX];
+	/* Path to infiniband class device in sysfs */
+	char			ibdev_path[IBV_SYSFS_PATH_MAX];
 };
 
 struct ibv_context_ops {
@@ -575,7 +633,16 @@ struct ibv_context_ops {
 	int			(*dealloc_pd)(struct ibv_pd *pd);
 	struct ibv_mr *		(*reg_mr)(struct ibv_pd *pd, void *addr, size_t length,
 					  enum ibv_access_flags access);
+	struct ibv_mr *		(*rereg_mr)(struct ibv_mr *mr,
+					    enum ibv_rereg_mr_flags flags,
+					    struct ibv_pd *pd, void *addr,
+					    size_t length,
+					    enum ibv_access_flags access);
 	int			(*dereg_mr)(struct ibv_mr *mr);
+	struct ibv_mw *		(*alloc_mw)(struct ibv_pd *pd, enum ibv_mw_type type);
+	int			(*bind_mw)(struct ibv_qp *qp, struct ibv_mw *mw,
+					   struct ibv_mw_bind *mw_bind);
+	int			(*dealloc_mw)(struct ibv_mw *mw);
 	struct ibv_cq *		(*create_cq)(struct ibv_context *context, int cqe,
 					     struct ibv_comp_channel *channel,
 					     int comp_vector);
@@ -612,15 +679,17 @@ struct ibv_context_ops {
 						uint16_t lid);
 	int			(*detach_mcast)(struct ibv_qp *qp, union ibv_gid *gid,
 						uint16_t lid);
+	void			(*async_event)(struct ibv_async_event *event);
 };
 
 struct ibv_context {
-	struct ibv_device         *device;
-	struct ibv_context_ops	   ops;
-	int                        cmd_fd;
-	int                        async_fd;
-	int                        num_comp_vectors;
-	void			  *abi_compat;
+	struct ibv_device      *device;
+	struct ibv_context_ops	ops;
+	int			cmd_fd;
+	int			async_fd;
+	int			num_comp_vectors;
+	pthread_mutex_t		mutex;
+	void		       *abi_compat;
 };
 
 /**
@@ -941,6 +1010,36 @@ static inline int ibv_post_recv(struct ibv_qp *qp, struct ibv_recv_wr *wr,
  */
 struct ibv_ah *ibv_create_ah(struct ibv_pd *pd, struct ibv_ah_attr *attr);
 
+/**
+ * ibv_init_ah_from_wc - Initializes address handle attributes from a
+ *   work completion.
+ * @context: Device context on which the received message arrived.
+ * @port_num: Port on which the received message arrived.
+ * @wc: Work completion associated with the received message.
+ * @grh: References the received global route header.  This parameter is
+ *   ignored unless the work completion indicates that the GRH is valid.
+ * @ah_attr: Returned attributes that can be used when creating an address
+ *   handle for replying to the message.
+ */
+int ibv_init_ah_from_wc(struct ibv_context *context, uint8_t port_num,
+			struct ibv_wc *wc, struct ibv_grh *grh,
+			struct ibv_ah_attr *ah_attr);
+
+/**
+ * ibv_create_ah_from_wc - Creates an address handle associated with the
+ *   sender of the specified work completion.
+ * @pd: The protection domain associated with the address handle.
+ * @wc: Work completion information associated with a received message.
+ * @grh: References the received global route header.  This parameter is
+ *   ignored unless the work completion indicates that the GRH is valid.
+ * @port_num: The outbound port number to associate with the address.
+ *
+ * The address handle is used to reference a local or global destination
+ * in all UD QP post sends.
+ */
+struct ibv_ah *ibv_create_ah_from_wc(struct ibv_pd *pd, struct ibv_wc *wc,
+				     struct ibv_grh *grh, uint8_t port_num);
+
 /**
  * ibv_destroy_ah - Destroy an address handle.
  */
@@ -967,6 +1066,14 @@ int ibv_attach_mcast(struct ibv_qp *qp, union ibv_gid *gid, uint16_t lid);
  */
 int ibv_detach_mcast(struct ibv_qp *qp, union ibv_gid *gid, uint16_t lid);
 
+/**
+ * ibv_fork_init - Prepare data structures so that fork() may be used
+ * safely.  If this function is not called or returns a non-zero
+ * status, then libibverbs data structures are not fork()-safe and the
+ * effect of an application calling fork() is undefined.
+ */
+int ibv_fork_init(void);
+
 END_C_DECLS
 
 #  undef __attribute_const
