@@ -1,7 +1,7 @@
 /*
  * Copyright (c) 2005 Topspin Communications.  All rights reserved.
  * Copyright (c) 2005 PathScale, Inc.  All rights reserved.
- * Copyright (c) 2006 Cisco Systems.  All rights reserved.
+ * Copyright (c) 2006 Cisco Systems, Inc.  All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -30,8 +30,6 @@
  * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
- *
- * $Id: cmd.c 10015 2006-10-31 15:52:42Z roland $
  */
 
 #if HAVE_CONFIG_H
@@ -43,6 +41,7 @@
 #include <stdlib.h>
 #include <errno.h>
 #include <alloca.h>
+#include <string.h>
 
 #include "ibverbs.h"
 
@@ -76,7 +75,9 @@ static int ibv_cmd_get_context_v2(struct ibv_context *context,
 
 	context->async_fd         = resp->async_fd;
 	context->num_comp_vectors = 1;
+	t->channel.context        = context;
 	t->channel.fd		  = cq_fd;
+	t->channel.refcnt	  = 0;
 	context->abi_compat       = t;
 
 	return 0;
@@ -210,7 +211,8 @@ int ibv_cmd_alloc_pd(struct ibv_context *context, struct ibv_pd *pd,
 
 	VALGRIND_MAKE_MEM_DEFINED(resp, resp_size);
 
-	pd->handle = resp->pd_handle;
+	pd->handle  = resp->pd_handle;
+	pd->context = context;
 
 	return 0;
 }
@@ -231,11 +233,11 @@ int ibv_cmd_dealloc_pd(struct ibv_pd *pd)
 int ibv_cmd_reg_mr(struct ibv_pd *pd, void *addr, size_t length,
 		   uint64_t hca_va, enum ibv_access_flags access,
 		   struct ibv_mr *mr, struct ibv_reg_mr *cmd,
-		   size_t cmd_size)
+		   size_t cmd_size,
+		   struct ibv_reg_mr_resp *resp, size_t resp_size)
 {
-	struct ibv_reg_mr_resp resp;
 
-	IBV_INIT_CMD_RESP(cmd, cmd_size, REG_MR, &resp, sizeof resp);
+	IBV_INIT_CMD_RESP(cmd, cmd_size, REG_MR, resp, resp_size);
 
 	cmd->start 	  = (uintptr_t) addr;
 	cmd->length 	  = length;
@@ -248,9 +250,10 @@ int ibv_cmd_reg_mr(struct ibv_pd *pd, void *addr, size_t length,
 
 	VALGRIND_MAKE_MEM_DEFINED(&resp, sizeof resp);
 
-	mr->handle  = resp.mr_handle;
-	mr->lkey    = resp.lkey;
-	mr->rkey    = resp.rkey;
+	mr->handle  = resp->mr_handle;
+	mr->lkey    = resp->lkey;
+	mr->rkey    = resp->rkey;
+	mr->context = pd->context;
 
 	return 0;
 }
@@ -290,8 +293,9 @@ static int ibv_cmd_create_cq_v2(struct ibv_context *context, int cqe,
 
 	VALGRIND_MAKE_MEM_DEFINED(resp, sizeof resp_size);
 
-	cq->handle = resp->cq_handle;
-	cq->cqe    = resp->cqe;
+	cq->handle  = resp->cq_handle;
+	cq->cqe     = resp->cqe;
+	cq->context = context;
 
 	return 0;
 }
@@ -318,8 +322,9 @@ int ibv_cmd_create_cq(struct ibv_context *context, int cqe,
 
 	VALGRIND_MAKE_MEM_DEFINED(resp, resp_size);
 
-	cq->handle = resp->cq_handle;
-	cq->cqe    = resp->cqe;
+	cq->handle  = resp->cq_handle;
+	cq->cqe     = resp->cqe;
+	cq->context = context;
 
 	return 0;
 }
@@ -386,20 +391,20 @@ int ibv_cmd_req_notify_cq(struct ibv_cq *ibcq, int solicited_only)
 }
 
 int ibv_cmd_resize_cq(struct ibv_cq *cq, int cqe,
-		      struct ibv_resize_cq *cmd, size_t cmd_size)
+		      struct ibv_resize_cq *cmd, size_t cmd_size,
+		      struct ibv_resize_cq_resp *resp, size_t resp_size)
 {
-	struct ibv_resize_cq_resp resp;
 
-	IBV_INIT_CMD_RESP(cmd, cmd_size, RESIZE_CQ, &resp, sizeof resp);
+	IBV_INIT_CMD_RESP(cmd, cmd_size, RESIZE_CQ, resp, resp_size);
 	cmd->cq_handle = cq->handle;
 	cmd->cqe       = cqe;
 
 	if (write(cq->context->cmd_fd, cmd, cmd_size) != cmd_size)
 		return errno;
 
-	VALGRIND_MAKE_MEM_DEFINED(&resp, sizeof resp);
+	VALGRIND_MAKE_MEM_DEFINED(resp, resp_size);
 
-	cq->cqe = resp.cqe;
+	cq->cqe = resp->cqe;
 
 	return 0;
 }
@@ -459,7 +464,8 @@ int ibv_cmd_create_srq(struct ibv_pd *pd,
 
 	VALGRIND_MAKE_MEM_DEFINED(resp, resp_size);
 
-	srq->handle = resp->srq_handle;
+	srq->handle  = resp->srq_handle;
+	srq->context = pd->context;
 
 	if (abi_ver > 5) {
 		attr->attr.max_wr = resp->max_wr;
@@ -608,6 +614,7 @@ int ibv_cmd_create_qp(struct ibv_pd *pd,
 
 	qp->handle 		  = resp->qp_handle;
 	qp->qp_num 		  = resp->qpn;
+	qp->context		  = pd->context;
 
 	if (abi_ver > 3) {
 		attr->cap.max_recv_sge    = resp->max_recv_sge;
@@ -1026,7 +1033,8 @@ int ibv_cmd_create_ah(struct ibv_pd *pd, struct ibv_ah *ah,
 
 	VALGRIND_MAKE_MEM_DEFINED(&resp, sizeof resp);
 
-	ah->handle = resp.handle;
+	ah->handle  = resp.handle;
+	ah->context = pd->context;
 
 	return 0;
 }
