@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2004, 2005 Topspin Communications.  All rights reserved.
+ * Copyright (c) 2007 Cisco Systems, Inc.  All rights reserved.
  *
  * This software is available to you under a choice of one of two
  * licenses.  You may choose to be licensed under the terms of the GNU
@@ -28,8 +29,6 @@
  * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
  * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
- *
- * $Id: ibverbs.h 9974 2006-10-27 23:46:16Z roland $
  */
 
 #ifndef IB_VERBS_H
@@ -58,19 +57,21 @@
 #define INIT		__attribute__((constructor))
 #define FINI		__attribute__((destructor))
 
+#define DEFAULT_ABI	"IBVERBS_1.1"
+
+#ifdef HAVE_SYMVER_SUPPORT
+#  define symver(name, api, ver) \
+	asm(".symver " #name "," #api "@" #ver)
+#  define default_symver(name, api) \
+	asm(".symver " #name "," #api "@@" DEFAULT_ABI)
+#else
+#  define symver(name, api, ver)
+#  define default_symver(name, api) \
+	extern __typeof(name) api __attribute__((alias(#name)))
+#endif /* HAVE_SYMVER_SUPPORT */
+
 #define PFX		"libibverbs: "
 
-struct ibv_sysfs_dev {
-	struct sysfs_class_device      *verbs_dev;
-	struct ibv_sysfs_dev	       *next;
-	int				have_driver;
-};
-
-struct ibv_driver {
-	ibv_driver_init_func	init_func;
-	struct ibv_driver      *next;
-};
-
 struct ibv_abi_compat_v2 {
 	struct ibv_comp_channel	channel;
 	pthread_mutex_t		in_use;
@@ -78,11 +79,7 @@ struct ibv_abi_compat_v2 {
 
 extern HIDDEN int abi_ver;
 
-extern HIDDEN int ibverbs_init(struct ibv_device ***list);
-
-extern HIDDEN int ibv_init_mem_map(void);
-extern HIDDEN int ibv_lock_range(void *base, size_t size);
-extern HIDDEN int ibv_unlock_range(void *base, size_t size);
+HIDDEN int ibverbs_init(struct ibv_device ***list);
 
 #define IBV_INIT_CMD(cmd, size, opcode)					\
 	do {								\
